#include "TH1F.h"
#include "TFile.h"
#include "TTree.h"
#include "TCanvas.h"

void reading(){
  // Open file 
  TFile* myFile = TFile::Open("tree.root"); // recommended way by R. Brun
  //TFile* myFile = new TFile("tree.root"); // Alternate way
  if (!myFile) {
    cout << "Error: cannot find file tree.root!" << endl;
    return;
  }
  // Get the tree from the root file
  TTree* myTree = (TTree*)myFile->Get("ExampleTree");
  if (!myTree) {
    cout << "Error: cannot find tree ExampleTree!" << endl;
    myFile->Close();
    return;
  }
  // Create a branch (which contains the data) and set its adress to a variable
  float myValue;
  TBranch* myBranch = myTree->GetBranch("gaussian");
  myBranch->SetAddress(&myValue);

  // Create histogram
  TH1F* myHisto = new TH1F("histo","",100,-5,5);

  // Loop over entries in tree and fill histogram
  int nev = myTree->GetEntries();
  for(int i = 0; i < nev; ++i){
    myTree->GetEvent(i);
    myHisto->Fill(myValue);
  }
  //myFile->Close();

  // Create canvas and set its options
  TCanvas* myCanvas = new TCanvas("plot","plot",500,500);
  myCanvas->SetFillColor(0);
  myCanvas->SetFrameFillColor(0);
  myCanvas->SetBorderMode(0);

  // Set histogram options and draw it
  gStyle->SetOptFit(1); // Adds the fit parameters to the statistics box
  myHisto->SetLineWidth(2);
  myHisto->SetFillColor(5);
  myHisto->SetXTitle("Value, arbitrary units");
  myHisto->SetYTitle("Entries");
  myHisto->Draw();
  // Fit
  myHisto->Fit("gaus");
  
  // Save plot as a root macro (could also save as eps/gif/jpg/png/...)
  myCanvas->Print("plot.C");
  myCanvas->Print("plot.png");
  myCanvas->Print("plot.eps");
}
